print("""'// src/index.tsx\nimport React from \'react\';\nimport { createRoot } from \'react-dom/client\';\nimport secureFiles from \'./components/secure_files/secure_files\';\nimport \'./static/css/index.css\';\nimport { loadConfig } from "@putkoff/abstract-logins"; // adjust path as needed\n\nconst container = document.getElementById("root");\nif (!container) {\n  throw new Error("No root element found");\n}\nconst root = createRoot(container);\n\nloadConfig()\n  .then(() => {\n    root.render(<secureFiles />);\n  })\n  .catch((err) => {\n    console.error("Failed to load config:", err);\n    // you might still render something fallback UI here\n    root.render(<secureFiles />);\n  });\n\n\ncreateRoot(container).render(\n  <React.StrictMode>\n    <secureFiles />\n  </React.StrictMode>\n);'""")
